==> AsposeCellsCloud-CellsApi-25.11.tar.gz: AsposeCellsCloud-CellsApi-25.11/docs/model/ScrollBar.md <==
# AsposeCellsCloud::Object::ScrollBar 

## Load the model package
```perl
use AsposeCellsCloud::Object::ScrollBar;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**CurrentValue** | **int** | Gets or sets the current value. |
**IncrementalChange** | **int** | Gets or sets the amount that the scroll bar or spinner is incremented a line scroll. |
**IsHorizontal** | **boolean** | Indicates whether this is a horizontal scroll bar. |
**Max** | **int** | Gets or sets the maximum value of a scroll bar or spinner range. |
**Min** | **int** | Gets or sets the minimum value of a scroll bar or spinner range. |
**PageChange** | **int** | Gets or sets page change |
**Shadow** | **boolean** | Indicates whether the shape has 3-D shading. |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/ScrollBar.md <==
# AsposeCellsCloud::Object::ScrollBar 

## Load the model package
```perl
use AsposeCellsCloud::Object::ScrollBar;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**CurrentValue** | **int** | Gets or sets the current value. |
**IncrementalChange** | **int** | Gets or sets the amount that the scroll bar or spinner is incremented a line scroll. |
**IsHorizontal** | **boolean** | Indicates whether this is a horizontal scroll bar. |
**Max** | **int** | Gets or sets the maximum value of a scroll bar or spinner range. |
**Min** | **int** | Gets or sets the minimum value of a scroll bar or spinner range. |
**PageChange** | **int** | Gets or sets page change |
**Shadow** | **boolean** | Indicates whether the shape has 3-D shading. |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
